# HISTORY

## 0.3.3

Update dev deps so we are using metadata 2.1 spec for pypi.

## 0.3.2

Updates to pin dependencies for Apistar 0.3.x and add Markdown rendering to pypi.org

## 0.3.1

Release for Apistar 0.3.x
